document.addEventListener('DOMContentLoaded', () => {
    const modal = document.getElementById('tradeModal');
    const newTradeBtn = document.getElementById('newTradeBtn');
    const cancelBtn = document.getElementById('cancelBtn');
    const tradeForm = document.getElementById('tradeForm');
    const tradesContainer = document.querySelector('.trades-container');

    // Sample trade data
    let trades = [];

    newTradeBtn.addEventListener('click', () => {
        modal.style.display = 'block';
    });

    cancelBtn.addEventListener('click', () => {
        modal.style.display = 'none';
        tradeForm.reset();
    });

    window.addEventListener('click', (e) => {
        if (e.target === modal) {
            modal.style.display = 'none';
            tradeForm.reset();
        }
    });

    tradeForm.addEventListener('submit', (e) => {
        e.preventDefault();
        
        const trade = {
            pair: document.getElementById('pair').value,
            type: document.getElementById('type').value,
            entry: parseFloat(document.getElementById('entry').value),
            exit: parseFloat(document.getElementById('exit').value),
            date: new Date().toISOString(),
            id: Date.now()
        };

        trades.unshift(trade);
        updateTradesList();
        modal.style.display = 'none';
        tradeForm.reset();
    });

    function updateTradesList() {
        tradesContainer.innerHTML = trades.map(trade => `
            <div class="trade-entry" data-id="${trade.id}">
                <div class="trade-header">
                    <h3>${trade.pair}</h3>
                    <span class="trade-date">${new Date(trade.date).toLocaleDateString()}</span>
                </div>
                <div class="trade-details">
                    <span class="trade-type ${trade.type}">${trade.type.toUpperCase()}</span>
                    <span class="trade-price">Entry: ${trade.entry}</span>
                    <span class="trade-price">Exit: ${trade.exit}</span>
                    <span class="trade-result ${trade.exit > trade.entry ? 'profit' : 'loss'}">
                        ${calculateProfit(trade)}
                    </span>
                </div>
            </div>
        `).join('');
    }

    function calculateProfit(trade) {
        const diff = trade.type === 'buy' 
            ? trade.exit - trade.entry
            : trade.entry - trade.exit;
        return diff.toFixed(5);
    }

    // Initial trades list update
    updateTradesList();
});